@@ -1,22 +1,11 @@
-tribinomprod=function(x1,x2,x3,TP,FN,FP,TN,NEP,NEN,perm)
+tribinomprod=function(x1,x2,x3,TP,FN,FP,TN,NEP,NEN)
 { n1=TP+FN
   n2=TN+FP
   n3=n1+n2+NEP+NEN
-  if(perm==1) # 12, 13, 23|1
-  { f1=dbinom(TP,size=n1,prob=x1)
-    f2=dbinom(TN,size=n2,prob=x2)
-    f3=dbinom(TP+FN+NEP,size=n3,prob=x3)
-  } else {
-    if(perm==2) # 21, 23, 13|2
-    { f1=dbinom(TN,size=n2,prob=x1)
-      f2=dbinom(TP+FN+NEP,size=n3,prob=x2)
-      f3=dbinom(TP,size=n1,prob=x3)
-      
-    } else { # 31, 32, 12|3
-      f1=dbinom(TP+FN+NEP,size=n3,prob=x1)
-      f2=dbinom(TP,size=n1,prob=x2)
-      f3=dbinom(TN,size=n2,prob=x3)
-    }}
+  # 12, 13, 23|1
+  f1=dbinom(TP,size=n1,prob=x1)
+  f2=dbinom(TN,size=n2,prob=x2)
+  f3=dbinom(TP+FN+NEP,size=n3,prob=x3)
   f1*f2*f3    
 }
 
@@ -24,7 +13,7 @@ tribinomprod=function(x1,x2,x3,TP,FN,FP,TN,NEP,NEN,perm)
 
 ###################################################
 tvineloglik.norm<-function(param,TP,FN,FP,TN,NEP,NEN,
-perm,gl,mgrid,qcondcop12,qcondcop13,tau2par12,tau2par13)
+gl,mgrid,qcondcop12,qcondcop13,tau2par12,tau2par13)
 { p=param[1:3]
   si=param[4:6]
   tau12=param[7]
@@ -58,7 +47,7 @@ perm,gl,mgrid,qcondcop12,qcondcop13,tau2par12,tau2par13)
   prob<-rep(NA,N)
   for(i in 1:N)
   { temp=tribinomprod(x1,x2,x3,TP[i],FN[i],FP[i],TN[i],
-                     NEP[i],NEN[i],perm)
+                     NEP[i],NEN[i])
     prob[i]= tensor(tensor(temp,gl$w,3,1),gl$w,2,1)%*%gl$w
   }
   -sum(log(prob))
@@ -67,8 +56,7 @@ perm,gl,mgrid,qcondcop12,qcondcop13,tau2par12,tau2par13)
 
 
 
-tVineCopulaREMADA.norm=function(TP,FN,FP,TN,
-perm,gl,mgrid,qcondcop12,qcondcop13,tau2par12,tau2par13,
+tVineCopulaREMADA.norm=function(TP,FN,FP,TN,gl,mgrid,qcondcop12,qcondcop13,tau2par12,tau2par13,
 NEP=rep(0,length(TP)),NEN=rep(0,length(TP)))
 { rTP=TP + 0.5*(TP==0)
   rFN=FN + 0.5*(FN==0)
@@ -80,21 +68,19 @@ NEP=rep(0,length(TP)),NEN=rep(0,length(TP)))
   SP=rTN/(rTN+rFP)
   PR=(rTP+rFN+rNEP)/(rTP+rFN+rTN+rFP+rNEP+rNEN)
   z=cbind(SE,SP,PR)
-  if(perm==1) {sel=1:3} else {if(perm==2){sel=c(2,3,1)} else {sel=c(3,1,2)}}
-  z=z[,sel]
   logitz=log(z/(1-z))
   p=apply(z,2,mean)
   si<-sqrt(apply(logitz,2,var))
   stau=cor(logitz,method="kendall")
   inipar=c(p,si,stau[1,2],stau[1,3])
-  est=nlm(tvineloglik.norm,inipar,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,
+  est=nlm(tvineloglik.norm,inipar,TP,FN,FP,TN,NEP,NEN,gl,mgrid,
           qcondcop12,qcondcop13,
           tau2par12,tau2par13,hessian=T)
   est
 }
 
 ###################################################
-tvineloglik.beta<-function(param,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,
+tvineloglik.beta<-function(param,TP,FN,FP,TN,NEP,NEN,gl,mgrid,
                            qcondcop12,qcondcop13,
                           tau2par12,tau2par13)
 { p=param[1:3]
@@ -127,7 +113,7 @@ tvineloglik.beta<-function(param,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,
   prob<-rep(NA,N)
   for(i in 1:N)
   { temp=tribinomprod(x1,x2,x3,TP[i],FN[i],FP[i],TN[i],
-                      NEP[i],NEN[i],perm)
+                      NEP[i],NEN[i])
   prob[i]= tensor(tensor(temp,gl$w,3,1),gl$w,2,1)%*%gl$w
   }
   -sum(log(prob))
@@ -136,21 +122,19 @@ tvineloglik.beta<-function(param,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,
 
 
 
-tVineCopulaREMADA.beta=function(TP,FN,FP,TN,perm,gl,mgrid,
+tVineCopulaREMADA.beta=function(TP,FN,FP,TN,gl,mgrid,
                                 qcondcop12,qcondcop13,
                                tau2par12,tau2par13,
                                NEP=rep(0,length(TP)),NEN=rep(0,length(TP)))
 { temp1=TP+FN
   temp2=TN+FP
   z=cbind(TP/temp1,TN/temp2,(temp1+NEP)/(temp1+temp2+NEP+NEN))
-  if(perm==1) {sel=1:3} else {if(perm==2){sel=c(2,3,1)} else {sel=c(3,1,2)}}
-  z=z[,sel]
   p<-apply(z,2,mean)
   si2<-apply(z,2,var)
   g=si2/p/(1-p)
   stau=cor(z,method="kendall")
   inipar=c(p,g,stau[1,2],stau[1,3])
-  est=nlm(tvineloglik.beta,inipar,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,
+  est=nlm(tvineloglik.beta,inipar,TP,FN,FP,TN,NEP,NEN,gl,mgrid,
           qcondcop12,qcondcop13,
           tau2par12,tau2par13,hessian=T)
   est
