@@ -1,4 +1,4 @@
-vinepmf.norm<-function(param,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,
+vinepmf.norm<-function(param,TP,FN,FP,TN,NEP,NEN,gl,mgrid,
                           qcondcop12,qcondcop13,qcondcop23,
                           tau2par12,tau2par13,tau2par23)
 { p=param[1:3]
@@ -30,13 +30,13 @@ vinepmf.norm<-function(param,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,
   prob<-rep(NA,N)
   for(i in 1:N)
   { temp=tribinomprod(x1,x2,x3,TP[i],FN[i],FP[i],TN[i],
-                      NEP[i],NEN[i],perm)
+                      NEP[i],NEN[i])
     prob[i]= tensor(tensor(temp,gl$w,3,1),gl$w,2,1)%*%gl$w
   }
   prob
 }
 
-vinepmf.beta<-function(param,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,
+vinepmf.beta<-function(param,TP,FN,FP,TN,NEP,NEN,gl,mgrid,
                           qcondcop12,qcondcop13,qcondcop23,
                           tau2par12,tau2par13,tau2par23)
 { p=param[1:3]
@@ -63,7 +63,7 @@ vinepmf.beta<-function(param,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,
   prob<-rep(NA,N)
   for(i in 1:N)
   { temp=tribinomprod(x1,x2,x3,TP[i],FN[i],FP[i],TN[i],NEP[i],
-                      NEN[i],perm)
+                      NEN[i])
     prob[i]= tensor(tensor(temp,gl$w,3,1),gl$w,2,1)%*%gl$w
   }
   prob
@@ -99,13 +99,13 @@ tvinepmf.norm<-function(param,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,
   prob<-rep(NA,N)
   for(i in 1:N)
   { temp=tribinomprod(x1,x2,x3,TP[i],FN[i],FP[i],TN[i],
-                      NEP[i],NEN[i],perm)
+                      NEP[i],NEN[i])
     prob[i]= tensor(tensor(temp,gl$w,3,1),gl$w,2,1)%*%gl$w
   }
   prob
 }
 
-tvinepmf.beta<-function(param,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,
+tvinepmf.beta<-function(param,TP,FN,FP,TN,NEP,NEN,gl,mgrid,
                            qcondcop12,qcondcop13,
                            tau2par12,tau2par13)
 { p=param[1:3]
@@ -130,19 +130,19 @@ tvinepmf.beta<-function(param,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,
   prob<-rep(NA,N)
   for(i in 1:N)
   { temp=tribinomprod(x1,x2,x3,TP[i],FN[i],FP[i],TN[i],
-                      NEP[i],NEN[i],perm)
+                      NEP[i],NEN[i])
     prob[i]= tensor(tensor(temp,gl$w,3,1),gl$w,2,1)%*%gl$w
   }
   prob
 }
 
 vine.vuong.norm=function(qcondcop12,qcondcop13,qcondcop23,tau2par12,tau2par13,tau2par23,
-                    param1,param2,TP,FN,FP,TN,perm,gl,mgrid,
+                    param1,param2,TP,FN,FP,TN,gl,mgrid,
                     NEP=rep(0,length(TP)),NEN=rep(0,length(TP)))
-{ prob1=vinepmf.norm(param1,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,qcondbvn,qcondbvn,qcondbvn,
+{ prob1=vinepmf.norm(param1,TP,FN,FP,TN,NEP,NEN,gl,mgrid,qcondbvn,qcondbvn,qcondbvn,
                   tau2par.bvn,tau2par.bvn,tau2par.bvn)
   n=length(prob1)
-  prob2=vinepmf.norm(param2,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,qcondcop12,qcondcop13,qcondcop23,
+  prob2=vinepmf.norm(param2,TP,FN,FP,TN,NEP,NEN,gl,mgrid,qcondcop12,qcondcop13,qcondcop23,
                   tau2par12,tau2par13,tau2par23)
   m=log(prob2/prob1)
   z=sqrt(n)*mean(m)/sd(m)
@@ -154,12 +154,12 @@ vine.vuong.norm=function(qcondcop12,qcondcop13,qcondcop23,tau2par12,tau2par13,ta
 }
 
 vine.vuong.beta=function(qcondcop12,qcondcop13,qcondcop23,tau2par12,tau2par13,tau2par23,
-                    param1,param2,TP,FN,FP,TN,perm,gl,mgrid,
+                    param1,param2,TP,FN,FP,TN,gl,mgrid,
                     NEP=rep(0,length(TP)),NEN=rep(0,length(TP)))
-{ prob1=vinepmf.norm(param1,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,qcondbvn,qcondbvn,qcondbvn,
+{ prob1=vinepmf.norm(param1,TP,FN,FP,TN,NEP,NEN,gl,mgrid,qcondbvn,qcondbvn,qcondbvn,
                   tau2par.bvn,tau2par.bvn,tau2par.bvn)
   n=length(prob1)
-  prob2=vinepmf.beta(param2,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,qcondcop12,qcondcop13,qcondcop23,
+  prob2=vinepmf.beta(param2,TP,FN,FP,TN,NEP,NEN,gl,mgrid,qcondcop12,qcondcop13,qcondcop23,
                   tau2par12,tau2par13,tau2par23)
   m=log(prob2/prob1)
   z=sqrt(n)*mean(m)/sd(m)
@@ -173,12 +173,12 @@ vine.vuong.beta=function(qcondcop12,qcondcop13,qcondcop23,tau2par12,tau2par13,ta
 
 
 tvine.vuong.norm=function(qcondcop12,qcondcop13,tau2par12,tau2par13,
-                         param1,param2,TP,FN,FP,TN,perm,gl,mgrid,
+                         param1,param2,TP,FN,FP,TN,gl,mgrid,
                          NEP=rep(0,length(TP)),NEN=rep(0,length(TP)))
-{ prob1=vinepmf.norm(param1,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,qcondbvn,qcondbvn,qcondbvn,
+{ prob1=vinepmf.norm(param1,TP,FN,FP,TN,NEP,NEN,gl,mgrid,qcondbvn,qcondbvn,qcondbvn,
                   tau2par.bvn,tau2par.bvn,tau2par.bvn)
   n=length(prob1)
-  prob2=tvinepmf.norm(param2,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,qcondcop12,qcondcop13,
+  prob2=tvinepmf.norm(param2,TP,FN,FP,TN,NEP,NEN,gl,mgrid,qcondcop12,qcondcop13,
                        tau2par12,tau2par13)
   m=log(prob2/prob1)
   z=sqrt(n)*(mean(m)+1/n)/sd(m)
@@ -190,12 +190,12 @@ tvine.vuong.norm=function(qcondcop12,qcondcop13,tau2par12,tau2par13,
 }
 
 tvine.vuong.beta=function(qcondcop12,qcondcop13,tau2par12,tau2par13,
-                         param1,param2,TP,FN,FP,TN,perm,gl,mgrid,
+                         param1,param2,TP,FN,FP,TN,gl,mgrid,
                          NEP=rep(0,length(TP)),NEN=rep(0,length(TP)))
-{ prob1=vinepmf.norm(param1,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,qcondbvn,qcondbvn,qcondbvn,
+{ prob1=vinepmf.norm(param1,TP,FN,FP,TN,NEP,NEN,gl,mgrid,qcondbvn,qcondbvn,qcondbvn,
                   tau2par.bvn,tau2par.bvn,tau2par.bvn)
   n=length(prob1)
-  prob2=tvinepmf.beta(param2,TP,FN,FP,TN,NEP,NEN,perm,gl,mgrid,qcondcop12,qcondcop13,
+  prob2=tvinepmf.beta(param2,TP,FN,FP,TN,NEP,NEN,gl,mgrid,qcondcop12,qcondcop13,
                        tau2par12,tau2par13)
   m=log(prob2/prob1)
   z=sqrt(n)*(mean(m)+1/n)/sd(m)
@@ -207,12 +207,12 @@ tvine.vuong.beta=function(qcondcop12,qcondcop13,tau2par12,tau2par13,
 }
 
 tvine2.vuong.norm=function(qcondcop12,qcondcop13,tau2par12,tau2par13,
-                          param1,param2,TP,FN,FP,TN,perm,gl,mgrid,
+                          param1,param2,TP,FN,FP,TN,gl,mgrid,
                           NEP=rep(0,length(TP)),NEN=rep(0,length(TP)))
-{ prob1=tvinepmf.norm(param1,TP,FN,FP,TN,perm,gl,mgrid,qcondbvn,qcondbvn,
+{ prob1=tvinepmf.norm(param1,TP,FN,FP,TN,gl,mgrid,qcondbvn,qcondbvn,
                        tau2par.bvn,tau2par.bvn)
   n=length(prob1)
-  prob2=tvinepmf.norm(param2,TP,FN,FP,TN,perm,gl,mgrid,qcondcop12,qcondcop13,
+  prob2=tvinepmf.norm(param2,TP,FN,FP,TN,gl,mgrid,qcondcop12,qcondcop13,
                        tau2par12,tau2par13)
   m=log(prob2/prob1)
   z=sqrt(n)*(mean(m))/sd(m)
@@ -224,12 +224,12 @@ tvine2.vuong.norm=function(qcondcop12,qcondcop13,tau2par12,tau2par13,
 }
 
 tvine2.vuong.beta=function(qcondcop12,qcondcop13,tau2par12,tau2par13,
-                          param1,param2,TP,FN,FP,TN,perm,gl,mgrid,
+                          param1,param2,TP,FN,FP,TN,gl,mgrid,
                           NEP=rep(0,length(TP)),NEN=rep(0,length(TP)))
-{ prob1=tvinepmf.norm(param1,TP,FN,FP,TN,perm,gl,mgrid,qcondbvn,qcondbvn,
+{ prob1=tvinepmf.norm(param1,TP,FN,FP,TN,gl,mgrid,qcondbvn,qcondbvn,
                        tau2par.bvn,tau2par.bvn)
   n=length(prob1)
-  prob2=tvinepmf.beta(param2,TP,FN,FP,TN,perm,gl,mgrid,qcondcop12,qcondcop13,
+  prob2=tvinepmf.beta(param2,TP,FN,FP,TN,gl,mgrid,qcondcop12,qcondcop13,
                        tau2par12,tau2par13)
   m=log(prob2/prob1)
   z=sqrt(n)*(mean(m))/sd(m)
